#
# spec file for package kodi
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Please edit kodi.spec and kodi.changes only. *-noX.* files are generated from
# kodi.* files with the pre_checkin.sh script
%define kodi_version Jarvis
%define _kodi_addons_dir %{_datadir}/kodi/addons
# set this parameter to enable building Kodi with ccache, debug information, etc.
%define dev_build 0
# kodi can be built without X support when openGL ES is used (mainly used on ARM boards used as media center)
%define noX_build 0
%if %{noX_build}
# no X build needs openGL ES
%bcond_with enable_opengl
%bcond_without enable_opengles
%else
%ifarch %arm armv6l armv6hl
%bcond_with enable_opengl
%bcond_without enable_opengles
%else
%bcond_without enable_opengl
%bcond_with enable_opengles
%endif
%endif

%define kodi_platform none
%define kodi_player none

Name:           kodi
Version:        16.1
Release:        3.6
Summary:        Media center (formerly known as XBMC)
License:        GPL-2.0+ and GPL-3.0+
Group:          Productivity/Multimedia/Video/Players
Url:            http://kodi.tv/
Source0:        https://github.com/xbmc/xbmc/archive/%{version}-%{kodi_version}.tar.gz
Source1:        kodi.SuSEFirewall2
Source2:        crossguid-8f399e8bd4.tar.gz
# AUTO-GENERATED using get_version.sh
Source3:        kodi.VERSION
Source10:       kodi.service
Source11:       kodi-noX.service
Patch1:         no-xbmc-symbolic-link.patch
Patch2:         kodi-texturepacker.patch
Patch3:         crossguid_build64.patch
Patch4:         add_rpi2_support.patch
Patch6:         kodi.cximage.gcc6.patch
BuildRequires:  avahi-devel
BuildRequires:  boost-devel
BuildRequires:  byacc
BuildRequires:  ccache
# needed to delete the fixed rpath introduced by smbclient
BuildRequires:  chrpath
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  flex
%if %{with enable_opengl}
BuildRequires:  ftgl-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  giflib-devel
BuildRequires:  glibc-devel
BuildRequires:  gmp-devel
BuildRequires:  gperf
BuildRequires:  hicolor-icon-theme
BuildRequires:  java
BuildRequires:  libcap-devel
%ifarch %ix86 x86_64
BuildRequires:  libcrystalhd-devel
%endif
BuildRequires:  libfaac-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpg-error-devel
BuildRequires:  libjasper-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  libmysqlclient-devel
#BuildRequires:  libsidplay2-1
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  libyajl-devel
BuildRequires:  lzo-devel
BuildRequires:  nasm
BuildRequires:  readline-devel
BuildRequires:  shairplay-devel
#BuildRequires:  sidplay-libs-devel
BuildRequires:  swig
BuildRequires:  tinyxml-devel
BuildRequires:  unzip
%if !%{noX_build}
BuildRequires:  xorg-x11-devel
%endif
BuildRequires:  yasm
BuildRequires:  zip

BuildRequires:  pkg-config
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(dcadec)
BuildRequires:  pkgconfig(dvdread)
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(fribidi)
%if %{with enable_opengl}
BuildRequires:  pkgconfig(glew)
%endif
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libass) >= 0.9.7
BuildRequires:  pkgconfig(libavcodec) = 56.60.100
BuildRequires:  pkgconfig(libavdevice) = 56.4.100
BuildRequires:  pkgconfig(libavfilter) = 5.40.101
BuildRequires:  pkgconfig(libavformat) = 56.40.101
BuildRequires:  pkgconfig(libavutil) = 54.31.100
BuildRequires:  pkgconfig(libbluray)  >= 0.7.0
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcec) >= 3.0.0
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libdca)
BuildRequires:  pkgconfig(libmicrohttpd)
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(libmpeg2)
BuildRequires:  pkgconfig(libmpg123)
BuildRequires:  pkgconfig(libnfs)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libpcrecpp)
BuildRequires:  pkgconfig(libplist)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(librtmp)
BuildRequires:  pkgconfig(libssh)
BuildRequires:  pkgconfig(libswresample) = 1.2.101
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libudev)
%if %{with enable_opengl}
BuildRequires:  pkgconfig(libva)
%endif
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(nettle)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(python)
BuildRequires:  pkgconfig(samplerate)
%if !%{noX_build}
BuildRequires:  pkgconfig(sdl2)
%endif
BuildRequires:  pkgconfig(smbclient)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(taglib) >= 1.8
BuildRequires:  pkgconfig(tinyxml2)
%if 0%{?suse_version} > 1320
# Otherwise fails with configure error on libcec because udev.pc file is not found
BuildRequires:  pkgconfig(udev)
%endif
BuildRequires:  pkgconfig(uuid)
%if %{with enable_opengl}
BuildRequires:  pkgconfig(vdpau)
%endif
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(zlib)

%if %{with enable_opengles}
%if "%{kodi_platform}" == "none"
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGLESv2-devel
%else
%if ("%{kodi_platform}" == "raspberry-pi") || ("%{kodi_platform}" == "raspberry-pi2")
BuildRequires:  raspberrypi-userland-devel
%endif
%endif
%endif

# kodi needs libnfs to access nfs sources, it is not automatically required
Requires:       libnfs
# kodi needs the same libtag version which was used to build against
%requires_eq    libtag1
# Manage player deps
%if %{kodi_player} == "omxplayer"
Requires:       omxplayer
%endif
# glxinfo is needed to check hw accel
%if 0%{?suse_version} >= 1220
%if !%{noX_build}
Requires:       Mesa-demo-x
Requires:       xdpyinfo
%endif
%endif

Obsoletes:      xbmc < %{version}
Provides:       xbmc = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    ppc64
%if %{noX_build}
Conflicts:      kodi
%else
Conflicts:      kodi-noX
%endif


%description
KODI media center is a free cross-platform media-player jukebox and
entertainment hub.  KODI can play a spectrum of of multimedia formats,
and featuring playlist, audio visualizations, slideshow, and weather
forecast functions, together third-party plugins.

%package devel
Summary:        Kodi Media center devel files
Group:          Development/Languages/C and C++
Requires:       %{name}
BuildArch:      noarch
%if %{noX_build}
Conflicts:      kodi-devel
%else
Conflicts:      kodi-noX-devel
%endif

%description devel
Development files for Kodi Media Center

%prep
%setup -q -n xbmc-%{version}-%{kodi_version}
%patch1
%patch2
%patch3
%patch4 -p0
%patch6 -p1


# Remove build time references so build-compare can do its work
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
FAKE_BUILDDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes)
for file in xbmc/GUIInfoManager.cpp xbmc/Application.cpp xbmc/utils/SystemInfo.cpp; do
  sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" $file
done
# remove the remaining occurencies in the source tree
for file in xbmc/interfaces/python/PythonSwig.cpp.template ; do
  sed -i -e "/PyModule_AddStringConstant.*__date__/ s/\${new Date()\.toString()}/$FAKE_BUILDDATETIME/"  $file
done

# Set the final version string 
cp %{SOURCE3} VERSION

# avoid long delays when powerkit isn't running
sed -i \
    -e '/dbus_connection_send_with_reply_and_block/s:-1:3000:' \
    xbmc/linux/*.cpp

cp %{SOURCE2} tools/depends/target/crossguid


%build

# build crossguid
make -C tools/depends/target/crossguid PREFIX=$PWD/tools/depends/target/crossguid LIBDIR=%{_lib}
		
chmod +x bootstrap
./bootstrap

# add crossguid to INCLUDES and LIBS
export INCLUDES="-I%{_builddir}/xbmc-%{version}-%{kodi_version}/tools/depends/target/crossguid/include"
export LIBS="-L%{_builddir}/xbmc-%{version}-%{kodi_version}/tools/depends/target/crossguid/%{_lib} -lcrossguid -luuid"

%if "%{kodi_platform}" == "raspberry-pi" || "%{kodi_platform}" == "raspberry-pi2"
export CXXFLAGS="$CXXFLAGS -I%{_includedir}/interface/vcos/pthreads -I%{_includedir}/interface/vmcs_host/linux"
%endif

%configure \
    --with-ffmpeg=shared \
    --enable-airplay \
    --enable-alsa \
    --enable-avahi \
    --enable-libcap \
    --enable-libcec \
    --enable-libusb \
    --enable-mid \
    --enable-mysql \
    --enable-nfs \
    --enable-pulse \
    --enable-rtmp \
    --enable-samba \
    --enable-shared \
    --enable-ssh \
    --enable-texturepacker \
    --enable-upnp \
    --enable-webserver \
%if %{with enable_opengl}
    --enable-vaapi \
    --enable-vdpau \
    --enable-gl \
%else
    --disable-vaapi \
    --disable-vdpau \
    --disable-gl \
%endif
%if %{with enable_opengles}
    --enable-gles \
%else
    --disable-gles \
%endif
%if "%{kodi_platform}" != "none"
    --disable-libbluray \
    --with-platform=%{kodi_platform} \
%endif
    --enable-libbluray \
%if "%{kodi_player}" != "none"
    --enable-player="%{kodi_player}" \
%endif
%ifarch armv7l armv7hl
    --enable-tegra \
    --disable-neon \
%endif
%if %{noX_build}
    --disable-x11 \
    --disable-xrandr \
    --disable-sdl \
    --disable-joystick \
%endif
%if %{dev_build}
    --enable-debug \
    --enable-ccache \
%endif
%if !%{dev_build}
    --disable-debug \
    --disable-ccache \
%endif
    --disable-optimizations \
    --disable-static 

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

# SuSEfirewall service description
install -D -m 644 %{_sourcedir}/kodi.SuSEFirewall2 %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/kodi

# Systemd service file
%if %{noX_build}
install -m 0644 -D %{SOURCE11} %{buildroot}/%{_unitdir}/kodi-noX.service
%else
install -m 0644 -D %{SOURCE10} %{buildroot}/%{_unitdir}/kodi.service
%endif

# remove the doc files from unversioned /usr/share/doc/kodi, they should be in versioned docdir
rm -r %{buildroot}/%{_datadir}/doc/

# copy manpages
install -m 644 -D docs/manpages/kodi-standalone.1 %{buildroot}%{_mandir}/man1/kodi-standalone.1
install -m 644 -D docs/manpages/kodi.bin.1 %{buildroot}%{_mandir}/man1/kodi.1

# remove win32 source files
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.addon/dlfcn-win32.cpp
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.addon/dlfcn-win32.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.addon/dlfcn-win32.cpp
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.addon/dlfcn-win32.h

# remove duplicate header files
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.addon/libXBMC_addon.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.addon/libXBMC_addon.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.codec/libXBMC_codec.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.codec/libXBMC_codec.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.gui/libXBMC_gui.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.gui/libXBMC_gui.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.pvr/libXBMC_pvr.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.pvr/libXBMC_pvr.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.guilib/libKODI_guilib.h

desktop-file-install \
 --dir=%{buildroot}%{_datadir}/applications \
 %{buildroot}%{_datadir}/applications/kodi.desktop

%fdupes %{buildroot}

%files
%defattr(-,root,root)
%doc copying.txt LICENSE.GPL docs/README.linux
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/kodi
%{_bindir}/kodi
%dir %{_libdir}/kodi
%{_libdir}/kodi/kodi.bin
%if !%{noX_build}
%{_libdir}/kodi/kodi-xrandr
%endif
%{_bindir}/kodi-standalone
%dir %{_libdir}/kodi/addons
%dir %{_libdir}/kodi/addons/library.xbmc.addon/
%{_libdir}/kodi/addons/library.xbmc.addon/*
%dir %{_libdir}/kodi/addons/library.xbmc.codec/
%{_libdir}/kodi/addons/library.xbmc.codec/*
%dir %{_libdir}/kodi/addons/library.xbmc.pvr/
%{_libdir}/kodi/addons/library.xbmc.pvr/*
%{_datadir}/xsessions/kodi.desktop
%{_datadir}/applications/kodi.desktop
%{_datadir}/icons/hicolor/*/*/*.png
%dir %{_datadir}/kodi
%dir %{_datadir}/kodi/media
%dir %{_datadir}/kodi/system
%dir %{_libdir}/kodi/system
%dir %{_datadir}/kodi/userdata
%{_datadir}/kodi/media/*
%{_datadir}/kodi/system/*
%{_libdir}/kodi/system/*
%{_datadir}/kodi/userdata/*
%{_mandir}/man1/kodi.1.gz
%{_mandir}/man1/kodi-standalone.1.gz
%dir %{_kodi_addons_dir}
%dir %{_kodi_addons_dir}/metadata.album.universal/
%{_kodi_addons_dir}/metadata.album.universal/*
%dir %{_kodi_addons_dir}/metadata.artists.universal/
%{_kodi_addons_dir}/metadata.artists.universal/*
%dir %{_kodi_addons_dir}/metadata.common.allmusic.com/
%{_kodi_addons_dir}/metadata.common.allmusic.com/*
%dir %{_kodi_addons_dir}/metadata.common.fanart.tv/
%{_kodi_addons_dir}/metadata.common.fanart.tv/*
%dir %{_kodi_addons_dir}/metadata.common.htbackdrops.com/
%{_kodi_addons_dir}/metadata.common.htbackdrops.com/*
%dir %{_kodi_addons_dir}/metadata.common.imdb.com/
%{_kodi_addons_dir}/metadata.common.imdb.com/*
%dir %{_kodi_addons_dir}/metadata.common.musicbrainz.org/
%{_kodi_addons_dir}/metadata.common.musicbrainz.org/*
%dir %{_kodi_addons_dir}/metadata.common.themoviedb.org/
%{_kodi_addons_dir}/metadata.common.themoviedb.org/*
%dir %{_kodi_addons_dir}/metadata.local/
%{_kodi_addons_dir}/metadata.local/*
%dir %{_kodi_addons_dir}/metadata.themoviedb.org/
%{_kodi_addons_dir}/metadata.themoviedb.org/*
%dir %{_kodi_addons_dir}/metadata.tvdb.com/
%{_kodi_addons_dir}/metadata.tvdb.com/*
%dir %{_kodi_addons_dir}/repository.xbmc.org/
%{_kodi_addons_dir}/repository.xbmc.org/*
%dir %{_kodi_addons_dir}/resource.uisounds.confluence/
%{_kodi_addons_dir}/resource.uisounds.confluence/*
%dir %{_kodi_addons_dir}/screensaver.xbmc.builtin.black/
%{_kodi_addons_dir}/screensaver.xbmc.builtin.black/*
%dir %{_kodi_addons_dir}/screensaver.xbmc.builtin.dim/
%{_kodi_addons_dir}/screensaver.xbmc.builtin.dim/*
%dir %{_kodi_addons_dir}/script.module.pil/
%{_kodi_addons_dir}/script.module.pil/*
%dir %{_kodi_addons_dir}/service.xbmc.versioncheck/
%{_kodi_addons_dir}/service.xbmc.versioncheck/*
%dir %{_kodi_addons_dir}/skin.confluence/
%{_kodi_addons_dir}/skin.confluence/*
%dir %{_kodi_addons_dir}/webinterface.default/
%{_kodi_addons_dir}/webinterface.default/*
%dir %{_kodi_addons_dir}/xbmc.codec/
%{_kodi_addons_dir}/xbmc.codec/*
%dir %{_kodi_addons_dir}/xbmc.addon/
%{_kodi_addons_dir}/xbmc.addon/*
%dir %{_kodi_addons_dir}/xbmc.core/
%{_kodi_addons_dir}/xbmc.core/*
%dir %{_kodi_addons_dir}/xbmc.gui/
%{_kodi_addons_dir}/xbmc.gui/*
%dir %{_kodi_addons_dir}/xbmc.json/
%{_kodi_addons_dir}/xbmc.json/*
%dir %{_kodi_addons_dir}/xbmc.metadata/
%{_kodi_addons_dir}/xbmc.metadata/*
%dir %{_kodi_addons_dir}/xbmc.pvr/
%{_kodi_addons_dir}/xbmc.pvr/*
%dir %{_kodi_addons_dir}/xbmc.python/
%{_kodi_addons_dir}/xbmc.python/*
%dir %{_kodi_addons_dir}/audioencoder.xbmc.builtin.aac/
%{_kodi_addons_dir}/audioencoder.xbmc.builtin.aac/*
%dir %{_kodi_addons_dir}/audioencoder.xbmc.builtin.wma/
%{_kodi_addons_dir}/audioencoder.xbmc.builtin.wma/*
%dir %{_kodi_addons_dir}/kodi.audiodecoder/
%{_kodi_addons_dir}/kodi.audiodecoder/*
%dir %{_kodi_addons_dir}/kodi.guilib/
%{_kodi_addons_dir}/kodi.guilib/*
%dir %{_kodi_addons_dir}/kodi.resource/
%{_kodi_addons_dir}/kodi.resource/*
%dir %{_kodi_addons_dir}/resource.language.en_gb/
%{_kodi_addons_dir}/resource.language.en_gb/*
%dir %{_kodi_addons_dir}/xbmc.audioencoder/
%{_kodi_addons_dir}/xbmc.audioencoder/*
%dir %{_kodi_addons_dir}/xbmc.webinterface/
%{_kodi_addons_dir}/xbmc.webinterface/*
%dir %{_kodi_addons_dir}/kodi.adsp
%{_kodi_addons_dir}/kodi.adsp/*
%dir %{_kodi_addons_dir}/library.kodi.adsp
%{_kodi_addons_dir}/library.kodi.adsp/*
%dir %{_kodi_addons_dir}/library.kodi.audioengine
%{_kodi_addons_dir}/library.kodi.audioengine/*
%dir %{_kodi_addons_dir}/metadata.common.theaudiodb.com
%{_kodi_addons_dir}/metadata.common.theaudiodb.com/*
%dir %{_kodi_addons_dir}/resource.images.weathericons.default
%{_kodi_addons_dir}/resource.images.weathericons.default/*
%{_libdir}/kodi/addon-helpers.cmake
%{_libdir}/kodi/addoptions.cmake
%{_libdir}/kodi/check_target_platform.cmake
%{_libdir}/kodi/handle-depends.cmake
%{_libdir}/kodi/kodi-config.cmake
%{_libdir}/kodi/prepare-env.cmake
%{_libdir}/kodi/xbmc-config.cmake
%dir %{_libdir}/kodi/addons/library.kodi.guilib/
%{_libdir}/kodi/addons/library.kodi.guilib/*
%dir %{_libdir}/kodi/addons/library.kodi.adsp
%{_libdir}/kodi/addons/library.kodi.adsp/*
%dir %{_libdir}/kodi/addons/library.kodi.audioengine
%{_libdir}/kodi/addons/library.kodi.audioengine/*

%if %{noX_build}
%{_unitdir}/kodi-noX.service
%else
%{_unitdir}/kodi.service
%endif

%files devel
%defattr(-,root,root)
%dir %{_includedir}/kodi
%{_includedir}/kodi/DVDDemuxPacket.h
%{_includedir}/kodi/libXBMC_addon.h
%{_includedir}/kodi/libXBMC_codec.h
%{_includedir}/kodi/libXBMC_pvr.h
%{_includedir}/kodi/xbmc_addon_cpp_dll.h
%{_includedir}/kodi/xbmc_addon_dll.h
%{_includedir}/kodi/xbmc_addon_types.h
%{_includedir}/kodi/xbmc_codec_types.h
%{_includedir}/kodi/xbmc_epg_types.h
%{_includedir}/kodi/xbmc_pvr_dll.h
%{_includedir}/kodi/xbmc_pvr_types.h
%{_includedir}/kodi/xbmc_scr_dll.h
%{_includedir}/kodi/xbmc_scr_types.h
%{_includedir}/kodi/xbmc_stream_utils.hpp
%{_includedir}/kodi/xbmc_vis_dll.h
%{_includedir}/kodi/xbmc_vis_types.h
%{_includedir}/kodi/xbmc_audioenc_dll.h
%{_includedir}/kodi/xbmc_audioenc_types.h
%{_includedir}/kodi/AEChannelData.h
%{_includedir}/kodi/kodi_audiodec_dll.h
%{_includedir}/kodi/kodi_audiodec_types.h
%{_includedir}/kodi/libKODI_guilib.h
%{_includedir}/kodi/kodi_adsp_dll.h
%{_includedir}/kodi/kodi_adsp_types.h
%{_includedir}/kodi/kodi_audioengine_types.h
%{_includedir}/kodi/libKODI_adsp.h
%{_includedir}/kodi/libKODI_audioengine.h

%changelog
* Sat Aug  6 2016 olaf@aepfle.de
- Remove unused libhdhomerun dependency
* Fri Jul 29 2016 olaf@aepfle.de
- kodi.cximage.gcc6.patch
  Sun Apr 24 11:55:31 UTC 2016 - sagiben at gmail dot com
- Version update to Kodi 16.1 Jarvis:
  https://kodi.tv/kodi-16-1-jarvis-mark-xvi
* Thu Mar 31 2016 obs@botter.cc
- reintroduce fix __date__ macro in PythonSwig.cpp.template from Jan 16 2015
* Thu Mar 10 2016 guillaume@opensuse.org
- Add add_rpi2_support.patch to add raspberry pi2 platform support
* Wed Mar  9 2016 guillaume@opensuse.org
- BuildRequires ftgl-devel and libva only for openGL builds
- Remove libplatform dep since it was/is an addon dep
  Thu Feb 25 08:57:53 UTC 2016 - sagiben at gmail dot com
- Version update to Kodi 16.0 Jarvis:
  http://kodi.wiki/view/Kodi_v16_(Jarvis)_changelog
* Fri Jan 29 2016 guillaume@opensuse.org
- Remove SDL2 dep for kodi-noX* builds
- Rework again platform and player management
  Tue Jan 19 19:01:29 UTC 2016 - sagiben at gmail dot com
- Merge Kenneth Perry change to re-enabled joystick support
* Thu Jan 14 2016 guillaume@opensuse.org
- Rework platform and player management to ease new platforms and
  players additions
- Add new flavors :
  * 'raspberry-pi' armv6 platform flavor (kodi-noX-raspberry-pi)
  * 'raspberry-pi2' armv7 platform flavor (kodi-noX-raspberry-pi2)
  Mon Oct 26 18:49:48 UTC 2015 - sagiben at gmail dot com
- Version update to Kodi 15.2 Isengard Final release
  http://kodi.tv/kodi-15-2-isengard-final-release/
* Mon Oct 19 2015 guillaume@opensuse.org
- Fix Tumbleweed build by adding: 'BuildRequires:  pkgconfig(udev)'
  Otherwise fails with configure error on libcec because udev.pc
  file is not found
* Fri Oct 16 2015 guillaume@opensuse.org
- Add systemd *.service files
  Mon Aug 17 03:33:41 UTC 2015 - sagiben at gmail dot com
- Version update to Kodi 15.1 Isengard Maintenance release
  http://kodi.tv/kodi-15-1-isengard-maintenance-release/
  Sat Aug  1 18:52:31 UTC 2015 - sagiben at gmail dot com
- Fix FindJsonCpp.cmake in some pvr.addons
* Thu Jul 23 2015 scarabeus@opensuse.org
- Run over with spec-cleaner
- kodi-xrandr is not around with noX variant
* Wed Jul 22 2015 scarabeus@opensuse.org
- Add hicolor-icon-theme to builddeps as that pkg provide some
  directories for us
* Wed Jul 22 2015 scarabeus@opensuse.org
- Tweak a bit download_pvr.sh to be easier to use
* Wed Jul 22 2015 sagiben@gmail.com scarabeus@opensuse.org
- Version update to Kodi 15.0 Isengard:
  http://kodi.wiki/view/Kodi_v15_(Isengard)_changelog
* Wed Jul  8 2015 olaf@aepfle.de
- Fix rsxs build in Factory
* Mon Apr 27 2015 aloisio@gmx.com
- Removed libhogweed2 build requirement to fix Factory/Tumbleweed
  build.
  Sat Mar 28 20:26:58 UTC 2015 - sagiben at gmail dot com
- Update to Kodi 14.2 Helix Bugfix release
  * Fix: Application stopped responding on Windows
  * Fix: Gap-less playback on MP3
  * Fix: Playback of rtmp protocol
  * Fix: Scanning of newly added episodes
  * Fix: Fix multipath source scanning
  * Fix: Loading external subtitles in some cases
  * Fix: packaging of PIL module on Android. This fixes some script error when using weather add-on
  * Fix: Fix video playback on all platform after refresh rate change
  * Fix: Various bugs that were present in PVR add-ons.
  * Fix: Save weather location
  * Fix: Fix filtering of foreign add-ons
  * Fix: ftps handling
  Sat Feb  7 18:11:31 UTC 2015 - sagiben at gmail dot com
- enable AirPlay support
  Tue Feb  3 19:53:15 UTC 2015 - sagiben at gmail dot com
- Update to Kodi 14.1 Helix Bugfix release
  * Fix: incorrect video screensize on Android AML devices
  * Fix: potential segfault when silencing audio
  * Fix: do not skip streaminfo if format is not know.
  * Fix: DXVA flickering on AMD
  * Fix: prevent possible over-flow in ALSA
  * Fix: possible sorting problems in library
  * Fix: possible problem in library navigation
  * Fix: don’t scroll text when it’s set to not do it
  * Fix: scroll text if it’s too long on spinner controls
  * Fix: don’t overlap PVR search labels
  * Fix: bug in DLNA client string on iOS
  * Fix: updated several PVR add-ons
  * Fix: remember played state of video when started from recently added
  * Fix: correct vsync on OSX
  * Fix: broken keyboard input
  * Fix: prevent crash on circular dependencies of add-ons
  * Fix: large file support on Android
  * Fix: random exiting on Android x86 builds (Nexus Player for example)
* Sat Jan 24 2015 obs@botter.cc
- Require: libnfs to access NFS sources (not automatically required)
* Fri Jan 16 2015 obs@botter.cc
- fix __date__ macro in PythonSwig.cpp.template
* Sat Jan 10 2015 obs@botter.cc
- delete RUNPATH from installed binary, fixes PM-130, referencing
  http://trac.kodi.tv/ticket/15497 and http://bugzilla.opensuse.org/show_bug.cgi?id=902421
- along the line ALSA support was included in Request #1545
* Fri Jan  9 2015 obs@botter.cc
- Require: xpdyinfo on != -noX version
* Thu Jan  8 2015 obs@botter.cc
- remove __DATE and __TIME__ from source tree and ffmpeg archive
  Fri Dec 12 06:21:30 UTC 2014 - sagiben at gmail dot com
- Update to Kodi 14.0 Helix
  * Project name was changed from XBMC to Kodi ( http://kodi.tv/introducing-kodi-14/ )
  * Different selectable keyboard layouts for the on screen keyboard.
  * Faster library scraping
  * Updated ffmpeg (2.4.4) including h.265 support
  * More control over add-ons and their updates in the add-on manager
  * "big font" size in Confluence
  * ATSC sub channels for PVR in the US
  * PVR window changes for easier navigation and new EPG views (now/next/channel)
  * Archives (zip, bin, etc) files can be directly browsed
* Wed Nov  5 2014 fisiu@opensuse.org
- Depends on xdpyinfo on x86{,-64}, fix pm#126.
  Sat Sep 13 04:41:09 UTC 2014 - sagiben at gmail dot com
- Update to 13.2
  * Bittstream conversion fix for some BD mkv iso rips
  * Fix labelcontrols with autowidth set were always marked as dirty (re-render)
  * Update included PVR add-on
  * Set “remote as keyboard” default to true for Android
  * Fix FTP TLS not working
  * Fix onplaybackstarted event for external players
  * Don’t show OSD menu DVD menu with mouse/touch
  * GetText and delete sound option for add-on developers
  * Fix overlapping subtitles
  * Fix accented letters. Example: “VARIéS” rather than “VARIÉS”
  * Prompt for master pin in case the add-on manager is locked
  * Update GUI translations
  * Update included add-ons
  * Fixed several bugs and memory leaks
* Tue Jun 10 2014 guillaume@opensuse.org
- Drop texture.patch since xbmc 13.1 does not need this fix anymore.
* Sat Jun  7 2014 fisiu@opensuse.org
- Update to 13.1:
  * Fix resume point of certain PVR items begin stale on playback.
  * Fix weirdness when certain TVs query XBMC’s UPnP server and it
    starts running a bunch of add-ons which cause popups on the XBMC
    machine.
  * Fix crash at exit while airplay is playing
  * Better recovery of VDPAU on errors.
  * Fixes for cropping of interlaced content using VDPAU.
  * Fix for FLAC tracks with large embedded images not playing.
  * Fix for crash if librtmp wasn’t available.
  * Fix for ffmpeg building on linux using later versions of librtmp.
  * Fix for broken m4a, mp4 playback with paplayer.
  * Fix for the hint text not being shown in editcontrols once unfocused.
  * Fix minor memory leak in PlayMedia builtin function.
  * Fix albumartist use in song smartplaylists.
  * Use unique client broadcast UID in the PVR api.
* Mon May 26 2014 guillaume@opensuse.org
- Fix build for non openGL builds (fix openGL ES)
- Run pre_checkin.sh script to sync xbmc-noX files
* Sat May 17 2014 fisiu@opensuse.org
- Update to 13.0 Gotham:
  * Dramatic Audio Engine Improvements
  * Improved UPnP capabilities
  * Settings Improvements
  * Making Subtitle Search Better
  * Stereoscopic 3D Rendering
  * Raspberry Pi and Android speed improvements
  * An Extended Python and JSON-RPC API for developers
  * Many minor fixes and improvements
- Add enable-external-ffmpeg.patch: build again system ffmpeg.
- Drop xbmc-12.2-subtitles.patch: fixed upstream.
- Drop samba4-fix.patch: fixed upstream.
- Drop git_rev.patch: fixed upstream.
* Mon Feb 17 2014 guillaume@opensuse.org
- Replace raspberrypi-gfx-devel package by raspberrypi-userland-devel
* Wed Feb 12 2014 guillaume@opensuse.org
- Add no X version support (mainly used by ARM boards)
  Fri Dec 27 08:44:21 UTC 2013 - sagiben at gmail dot com
- - New upstream version 12.3
* Wed Oct  2 2013 guillaume@opensuse.org
- Fix Raspberry Pi (armv6) build:
  * Add include path for raspberrypi-gfx headers
  * Add texture.patch to fix include path for XBMCTex.cpp
  * Add disable_omxplayer_3d_support.patch to disable 3D support
  from omxplayer since X11/GLES does not support it (only EGL)
* Mon Sep 16 2013 guillaume@opensuse.org
- Enable omxplayer by default (player for raspberry pi ARMv6 board)
* Mon Sep 16 2013 guillaume@opensuse.org
- Protect enable_rpi_build condition with %%ifarch armv6
  Mon Sep 16 03:06:17 UTC 2013 - sagiben at gmail dot com
- Enable MythTV pvr addon
- Set git revision
* Fri Sep 13 2013 guillaume@opensuse.org
- Add options to enable/disable openGL / openGL ES support
  * ARM default: openGL ES
  * Other arch: openGL
* Fri Sep 13 2013 guillaume@opensuse.org
- Add support for omxplayer for raspberry pi board (armv6)
* Mon Sep  9 2013 guillaume@opensuse.org
- Add support for Raspberry Pi ARM board (armv6)
* Mon Sep  9 2013 guillaume@opensuse.org
- Add libcec and airplay support
* Wed Sep  4 2013 fisiu@opensuse.org
- Add samba4-fix.patch: fix build against samba4 - enabled for
  openSUSE >= 13.1.
* Wed Sep  4 2013 fisiu@opensuse.org
- Add Requires: Mesa-demo-x for openSUSE >= 12.2, fix pm#84.
* Mon Aug 26 2013 guillaume@opensuse.org
- Make use of %%configure macro
* Fri Aug 23 2013 guillaume@opensuse.org
- Fix builds:
  * XBMC 12.2 depends on FFMPEG1, not FFMPEG2
  * crystalhd is only built for x86/x86_64
* Mon Jun  3 2013 fisiu@opensuse.org
- Add xbmc-12.2-subtitles.patch: embeded fonts' rendering fix.
  Fri May 10 16:35:39 UTC 2013 - sagiben at gmail dot com
- New upstream version 12.2
  Fri Mar 29 03:52:57 UTC 2013 - sagiben at gmail dot com
- New upstream version 12.1
* Mon Feb  4 2013 fisiu@opensuse.org
- Spec file cleanup.
- Enable support for airplay.
- Detect libtag version and use it as Requires.
* Sun Feb  3 2013 p.seiler@linuxmail.org
- small changes in the spec file for cleanness
  replaced BuildRequires to simple java
  removed outcommented stuff like BuildRequires and so on
* Fri Feb  1 2013 hvogel@opensuse.org
-Include PVR add-ons, they are the main feature of Frodo
* Fri Feb  1 2013 p.seiler@linuxmail.org
- added explizit libtag-devel 1.8 requirement to prevent conflict with openSUSE libtag package
* Thu Jan 31 2013 p.seiler@linuxmail.org
- corrected licenses in spec file to prevent build warning
- added devel package to prevent build error
* Wed Jan 30 2013 p.seiler@linuxmail.org
- new upstream version 12.0
  + HD audio support, including DTS-MA and Dolby True-HD, via the
  new XBMC AudioEngine
  + Live TV and PVR support
  + h.264 10bit (aka Hi10P) video software decoding for anime
  + Improved image support, allowing the database to accomodate
  numerous additional image types
  + Improved Airplay support across all platforms
  + Improved controller support
  + Advanced Filtering in the library
  + Advanced UPnP sharing
  + Translations now powered by Transifex
  Sun Apr  8 14:39:48 UTC 2012 - sagiben at gmail com
- New upstream version 11.0
* Fri Dec  9 2011 ismail@namtrac.org
- Remove _service its fragile
- Spec cleanup
* Thu Dec  8 2011 ismail@namtrac.org
- Depend on libbluray1
* Mon Nov 28 2011 sagiben@gmail.com
- fix build with gcc-4.6. Flags to the Linker must be passed via -Wl,.
  Patch was taken from xbmc ticket #11383, http://trac.xbmc.org/ticket/11383
* Tue May  3 2011 fisiu@opensuse.org
- disable-hal for openSUSE >= 11.4
* Fri Apr 15 2011 andrea@links2linux.de
- New upstream version 10.1
* Mon Jan 24 2011 andrea@links2linux.de
- enabled crystalhd and bluray support (dependencies now available)
* Mon Jan 24 2011 andrea@links2linux.de
- enabled VA-API (not sure if it works), FAAC, ssh, optimizations
* Wed Jan 12 2011 andrea@links2linux.de
- New upstream version 10.0 (Thanks fedora)
* Sun Feb  7 2010 andrea@links2linux.de
- fixed docs location
* Sat Feb  6 2010 andrea@links2linux.de
- added bool.patch to fix a startup segmentation fault
- do NOT use ffmpeg external libraries because they make xbmc crashes when you try to reproduce a video
